#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 62 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm

use esmith::TestUtils qw(scratch_copy);

use_ok("esmith::AccountsDB");
use esmith::db;
use vars qw($a);

my $conf = scratch_copy('10e-smith-lib/accounts.conf');
$a = esmith::AccountsDB->open($conf);
isa_ok($a, 'esmith::AccountsDB');
is( $a->get("global")->prop('type'), "system", "We can get stuff from the db");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 91 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 107 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm
foreach my $t (qw(users groups pseudonyms)) {
    my @list = $a->$t();
    ok(@list, "Got a list of $t");
    isa_ok($list[0], 'esmith::DB::db::Record');
}

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 137 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm
ok($a->is_user_in_group('bart', 'simpsons'), "Bart is in group Simpsons");
ok(not($a->is_user_in_group('moe', 'simpsons')), "Moe is not in group Simpsons");
ok(not(defined $a->is_user_in_group('moe', 'flanders')), "No such group as Flanders");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 157 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm
my @groups = $a->user_group_list('bart');
is_deeply(\@groups, ['simpsons'], "Bart's group list is 'simpsons'");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 183 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm
my @groups = $a->groups();
$a->remove_user_from_groups('maggie', map { $_->key() } @groups);
my @mg = $a->user_group_list('maggie');
is(scalar @mg, 0, "Maggie has been removed from all groups");
$a->add_user_to_groups('maggie', 'simpsons');
@mg = $a->user_group_list('maggie');
is_deeply(\@mg, ['simpsons'], "Maggie has been added to group 'simpsons'");
$a->remove_user_from_groups('maggie', 'simpsons');
@mg = $a->user_group_list('maggie');
is_deeply(\@mg, [], "Maggie's been removed from all groups again");
$a->set_user_groups('maggie', 'simpsons');
@mg = $a->user_group_list('maggie');
is_deeply(\@mg, ['simpsons'], "Maggie's groups have been set to: 'simpsons'");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 260 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm
my $user = 'bart';
ok($a->pseudonyms(), "There are pseudonyms in the accounts db");
$a->remove_user_auto_pseudonyms($user);
ok(! $a->get('bart.simpson'), "Removed dot-pseudonym");
ok(! $a->get('bart_simpson'), "Removed underbar-pseudonym");
$a->create_user_auto_pseudonyms($user);
ok($a->get('bart.simpson'), "Created dot-pseudonym");
ok($a->get('bart_simpson'), "Created underbar-pseudonym");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 367 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm

my @users     = $a->users();
my $user      = 'bart';
my $rec       = $a->get($user);
my $firstName = $rec->prop("FirstName");
my $lastName  = $rec->prop("LastName");
my $up        = $a->underbar_pseudonym($user);
is($up, "bart_simpson", "Underbar pseudonym created correctly");
my $dp        = $a->dot_pseudonym($user);
is($dp, "bart.simpson", "Underbar pseudonym created correctly");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 403 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm

my $numActiveUsers = scalar $a->activeUsers();
like($numActiveUsers, qr/[0-9]+/, "active users returns a number");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 425 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm
SKIP: {
    skip "Must be root to run get_next_uid" if $<;
    my $u = $a->get_next_uid();
    ok($u > 5000, "UID should be greater than 5000");
    ok(! getpwuid($u), "UID should not yet exist");
}

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 470 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm

isnt($a->new_record("root", {type=>'system'}), "OK", 
    "can't create existing account");
is($a->get("nobody"), undef, "nobody doesn't exist in db");
isnt($a->new_record("nobody", {type=>'system'}), "OK",
    "can't create account in /etc/passwd");
isnt($a->new_record("screwy", {type=>'user'}), undef, 
    "created a regular user");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 504 root/usr/lib/perl5/site_perl/esmith/AccountsDB.pm

is($a->validate_account_name("root"), "OK", "root is a valid name");
isnt($a->validate_account_name("^root"), "OK", "^root is not a valid name");
is(esmith::AccountsDB::validate_account_name("root"), "OK", "called as a function");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

