#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/HostsDB.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 52 root/usr/lib/perl5/site_perl/esmith/HostsDB.pm

use_ok("esmith::HostsDB");

$H = esmith::HostsDB->open('10e-smith-lib/hosts.conf');
isa_ok($H, 'esmith::HostsDB');
is( $H->get("otherhost.mydomain.xxx")->prop('InternalIP'), "192.168.1.3", 
                                    "We can get stuff from the db");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 77 root/usr/lib/perl5/site_perl/esmith/HostsDB.pm


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 102 root/usr/lib/perl5/site_perl/esmith/HostsDB.pm

$db = esmith::HostsDB->open('10e-smith-lib/hosts.conf');
isa_ok($db, 'esmith::HostsDB');
can_ok($db, 'hosts');
my @hosts = $db->hosts();
isnt( @hosts, 0 );
is_deeply(\@hosts, [$db->get_all_by_prop('type' => 'host')]);


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 130 root/usr/lib/perl5/site_perl/esmith/HostsDB.pm

use esmith::ConfigDB;

my $hosts_file = '10e-smith-lib/propogate_hosts.conf';
END { unlink $hosts_file }

my $db     = esmith::HostsDB->create($hosts_file);

use esmith::TestUtils qw(scratch_copy);
my $c_scratch = scratch_copy('10e-smith-lib/configuration.conf');
my $config = esmith::ConfigDB->open($c_scratch);
isa_ok($config, 'esmith::ConfigDB');

my $name   = $config->get('SystemName')->value;

# setup some dummy hosts to propogate.
foreach my $host ( "$name.tofu-dog.com", "$name.wibble.org",
                     "wibble.$name.org", "yarrow.hack" )
{
    $db->new_record($host, { type => 'host',  HostType => 'Self',
                             ExternalIP => '', InternalIP => ''
                           });
}

$db->reload;
my @new_hosts = $db->propogate_hosts($name, "armondo");
my @hosts = $db->hosts;
is( @hosts, 4 );
is_deeply( [sort map { $_->key } @hosts], 
           [sort +('armondo.tofu-dog.com',
                   'armondo.wibble.org',
                   "wibble.$name.org",
                   'yarrow.hack',
                  )] 
);

is( @new_hosts, 2 );
is_deeply( [sort map { $_->key } @new_hosts],
           [sort qw(armondo.tofu-dog.com armondo.wibble.org)] 
         );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 202 root/usr/lib/perl5/site_perl/esmith/HostsDB.pm

my $h = esmith::HostsDB->open('10e-smith-lib/hosts.conf');
my @hosts = $h->get_hosts_by_domain('otherdomain.xxx');
is(scalar(@hosts), 2, "Found two hosts in otherdomain.xxx");
isa_ok($hosts[0], 'esmith::DB::Record');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

