#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/config.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 49 root/usr/lib/perl5/site_perl/esmith/config.pm

use_ok('esmith::config');
chdir '10e-smith-lib';

%Expect = ( foo              => 'bar',
'this key'       => 'has whitespace',
'that key '      => 'has trailing whitespace',
' another key'   => 'has leading whitespace',
'this value'     => ' has leading whitespace',
'that value'     => 'has trailing whitespace ',
'tricky value'   => 'with=equals.',
          );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 79 root/usr/lib/perl5/site_perl/esmith/config.pm

my %config;
tie %config, 'esmith::config', 'dummy.conf';
ok( tied %config,                'tie worked' );
is( $config{foo}, 'bar',         '  theres stuff in it' );
ok( !exists $config{FILENAME},   '  it only contains config info');
is( tied(%config)->{FILENAME},     'dummy.conf',
'  and the real object is inside');

tie %config, 'esmith::config', 'I_dont_exist';
ok( tied %config,        'tying a non-existant file' );
is( keys %config, 0,    '  and its empty' );
$config{foo} = 42;
isnt( -s 'I_dont_exist', 0 );
untie %config;
ok( unlink 'I_dont_exist' );

$ENV{ESMITH_CONFIG_DB} = "dummy.conf";
tie %config, 'esmith::config';
ok( tied %config,                'tie to ESMITH_CONFIG_DB worked' );
is_deeply(\%config, \%Expect, "  picked up data");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 120 root/usr/lib/perl5/site_perl/esmith/config.pm

my %config;
my $obj = tie %config, 'esmith::config', 'dummy.conf';
is( $obj->filename, 'dummy.conf', 'filename()' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 160 root/usr/lib/perl5/site_perl/esmith/config.pm

my $config = esmith::config::_readconf('dummy.conf');
isnt( keys %$config, 0,  '_readconf() got something' );
is_deeply( $config, \%Expect, '  read in the right values' );

$config = esmith::config::_readconf('I_dont_exist');
isa_ok( $config, 'HASH', '_readconf from a non-existent file' );
is( keys %$config, 0,    '  and its empty' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 222 root/usr/lib/perl5/site_perl/esmith/config.pm

my $scratch = 'scratch.conf';
ok( esmith::config::_writeconf($scratch, \%Expect),  
'_writeconf() says it worked' );
is_deeply( esmith::config::_readconf($scratch), \%Expect,   
'   wrote the right things' );
unlink $scratch;


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 496 root/usr/lib/perl5/site_perl/esmith/config.pm

my $scratch = 'scratch.conf';
tie %config, 'esmith::config', $scratch;
ok( tied %config,        'tying a non-existant file' );
is( keys %config, 0,    '  and its empty' );
$config{fibble} = 'blah';
isnt( keys %config, 0,  '  and its not empty now' );
%config = ();
is( keys %config, 0,    '  and CLEAR made it empty again' );
unlink $scratch;


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

