#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 22 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm

use_ok('esmith::DB::db::Record');
use_ok('esmith::DB::db');

use File::Copy;
$Scratch_Conf = '10e-smith-lib/scratch.conf';
copy('10e-smith-lib/db_dummy.conf', $Scratch_Conf);
END { unlink $Scratch_Conf }

$DB = esmith::DB::db->open($Scratch_Conf);
$Squid = $DB->get('Squid');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 94 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm
is( $Squid->key, 'Squid', 'key()' );

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 106 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm
is_deeply( {$Squid->props}, {arms => 10, species => 'Loligo', 
                             type => 'cephalopod'},          'props()' );

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 128 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm

is( $Squid->prop('arms'), 10,     'prop()' );
$Squid->set_prop('arms', 1000);
is( $Squid->prop('arms'), 1000,   'set_prop()' );

is( $Squid->prop('type'), 'cephalopod',         'prop() type get' );
$Squid->set_prop('type', 'tree dweller');
is( $Squid->prop('type'), 'tree dweller',       'set_prop() type set' );

$Squid->set_prop('bar', 'foo | bar');
is( $Squid->prop('bar'), 'foo  bar',           'prop/set_prop with pipes - pipe stripped' );

{
    my $warning = '';
    local $SIG{__WARN__} = sub { $warning = join '', @_ };
    $Squid->prop('bar', 'foo');
    like( $warning, qr/^prop\(\) got extra arguments 'foo'. Maybe you ment set_prop\(\)\?/,  'prop()/set_prop() mixup warns' );

    $warning = '';
    is( $Squid->prop('I_dont_exist'), undef,  'prop() on non-existent prop' );
    is( $warning, '', '  no warning' );

    $warning = '';
    $Squid->set_prop('I_dont_exist', undef);
    is( $Squid->prop('I_dont_exist'), '', 'set_prop() with undef value' );
    is( $warning, '', '  no warning' );
    $Squid->delete_prop('I_dont_exist');
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 205 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm
is( $Squid->delete_prop('species'), 'Loligo', 
                                  'delete_prop() returns the old value' );
is_deeply( {$Squid->props}, {arms => 1000, bar => 'foo  bar',
                             type => 'tree dweller' },
                                  '  and deletes' );

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 231 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm

my $octopus = $DB->get('Octopus');
$octopus->merge_props( arms => '8 + 2i', name => 'Fluffy', pipe => 'not |');
is_deeply( {$octopus->props}, { arms => '8 + 2i', type => 'cephalopod',
                                species => '', name => 'Fluffy',
                                pipe => 'not ' },   'merge_props()' );
$octopus->merge_props( type => 'foo' );
is_deeply( {$octopus->props}, { arms => '8 + 2i', type => 'foo',
                                species => '', name => 'Fluffy',
                                pipe => 'not ' },   '  with type' );

$octopus->merge_props( { type => 'foo' } );
like( $_STDERR_, qr/^merge_props\(\) was accidentally passed a hash ref/m,
                                       '  anti-hash ref protection');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 274 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm

my $octopus = $DB->get('Octopus');

eval { $octopus->reset_props( { type => 'foo' } ); };
like( $_STDERR_, qr/^reset_props\(\) was accidentally passed a hash ref/m,
                                       '  anti-hash ref protection');

$octopus->reset_props( arms => 8, name => 'Rupert', type => 'foo' );
is_deeply( {$octopus->props}, { arms => '8', name => 'Rupert',
                                type => 'foo' },   'reset_props' );

eval { $octopus->reset_props( arms => '8 + 2i', name => 'Fluffy', 
                              pipe => 'not ') };
like( $@, qr/^You must have a type property/,  '  you must have a type');


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 317 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm
my $foo = $DB->get('Foo');
$foo->delete;
ok( !$DB->get('Foo'), 'delete()' );

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 334 root/usr/lib/perl5/site_perl/esmith/DB/db/Record.pm

is( $Squid->show, <<SQUID, 'show' );
Squid
  arms = 1000
   bar = foo  bar
  type = tree dweller
SQUID


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

