#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/DB/db.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 23 root/usr/lib/perl5/site_perl/esmith/DB/db.pm
use_ok('esmith::DB::db');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 64 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

$Scratch_Conf = '10e-smith-lib/scratch.conf';
unlink $Scratch_Conf;
$db = esmith::DB::db->create($Scratch_Conf);
END { unlink $Scratch_Conf }

isa_ok( $db, 'esmith::DB::db', 'create()' );
ok( -e $Scratch_Conf, 'created a new config file' ); 
ok(! esmith::DB::db->create($Scratch_Conf), 
                              'create() wont walk over an existing config' );
like( esmith::DB::db->error, qr/^File exists/,    '  right error message' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 120 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

unlink $Scratch_Conf;
ok( !esmith::DB::db->open($Scratch_Conf),  'open() on a non-existent db' );
is( esmith::DB::db->error, "File doesn't exist", '  right error' );

esmith::DB::db->create($Scratch_Conf);
$DB = esmith::DB::db->open($Scratch_Conf);
isa_ok( $DB, 'esmith::DB::db' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 147 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

ok( my $db = esmith::DB::db->open_ro($Scratch_Conf), 
    'open_ro on a non-existent db');
eval { $db->new_record('foo', { type => 'bar' }) };
like( $@, qr/^This DB is opened read-only/ );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 218 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

use esmith::TestUtils qw(scratch_copy);
my $scratch = scratch_copy('10e-smith-lib/db_dummy.conf');
my %db = esmith::DB::db->as_hash($scratch);

my %expect = (     Foo      => { type => 'Bar' },
                   Night    => { type => 'Day' },
                   Squid    => { type    => 'cephalopod',
                                 arms    => 10,
                                 species => 'Loligo' },
                   Pipe     => { type    => 'art',
                                 pipe    => 'this is not a | got that?',},
                   Haiku    => { type    => 'poem',
                                 words   => 
"Damian Conway\nGod damn! Damian Conway\nDamian Conway",
                               },
                   Octopus  => { type    => 'cephalopod',
                                 arms    => 8,
                                 species => '',
                               }
             );

is_deeply( \%db, \%expect );

%db = esmith::DB::db->open($scratch)->as_hash;
is_deeply( \%db, \%expect );
                   

my $db2 = esmith::DB::db->open($Scratch_Conf);
my $something = $DB->new_record('something', { type => "wibble" });
isa_ok( $something, 'esmith::DB::db::Record', 'new record in 1st DB' );

ok( !$db2->get('something'),    '  2nd DB still cant see new record' );
ok( $db2->reload,               '  reload' );
ok( $db2->get('something'),     '  2nd DB can see new record' );

$something->delete;


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 274 root/usr/lib/perl5/site_perl/esmith/DB/db.pm
is( $db->file, $Scratch_Conf, 'file()' );

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 288 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

my $record = $DB->new_record('Big Brother', { year => 1984,
                                              day => 'night',
                                              type => 'Govt',
                             });
isa_ok( $record, 'esmith::DB::db::Record', 'new_record' );
is( $record->key,  'Big Brother',  'key' );
is( $record->prop('type'), 'Govt',         'type' );
is_deeply( {$record->props}, {year => 1984, day => 'night', type => 'Govt'}, 
                                                           'props' );
is( $record->prop('year'), 1984,        'prop() get' );
is( $record->prop('day'),  'night',     'prop() get again' );


$record = $DB->new_record('No props');
isa_ok( $record, 'esmith::DB::db::Record', 'new_record() w/o props' );
is( $record->key,  'No props', '  key' );

my $db2 = esmith::DB::db->open($DB->file);
ok( $db2->get('No props'), '  can be gotten' );

$record->delete;


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 334 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

my $rec = $DB->get('Big Brother');
isa_ok( $rec, 'esmith::DB::db::Record', 'get' );
is( $rec->key, 'Big Brother',  '  right key' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 358 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

$DB->new_record('Borg', { type => 'Govt', resistance => 'futile' });
my @records = $DB->get_all;
is( @records, 2, 'get_all' );
ok( !(grep { !$_->isa('esmith::DB::db::Record') } @records),
                                          '  theyre all records' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 381 root/usr/lib/perl5/site_perl/esmith/DB/db.pm

$DB->new_record('Pretz', { type => 'snack', flavor => 'old fashion' });
my @records = $DB->get_all_by_prop(type => 'Govt');
is( @records, 2, 'get_all_by_prop() type' );
ok( !(grep { $_->prop('type') ne 'Govt' } @records), 
                                   '  theyre the right type' );

$DB->new_record('Pork lips', { type => 'snack', flavor => 'old fashion' });
@records = $DB->get_all_by_prop(flavor => 'old fashion');
is( @records, 2, 'get_all_by_prop()' );
ok( !(grep { $_->prop('flavor') ne 'old fashion' } @records),
                                   '  they have the right properties' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 406 root/usr/lib/perl5/site_perl/esmith/DB/db.pm
ok($DB->list_by_type("Govt"), "list_by_type *deprecated*");

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

