#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/util/network.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 24 root/usr/lib/perl5/site_perl/esmith/util/network.pm
use_ok('esmith::util::network');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 59 root/usr/lib/perl5/site_perl/esmith/util/network.pm

use esmith::util::network qw(cleanIP);

my %ips = (
    '000.000.000.000'      => '0.0.0.0',
    '0.0.0.0'              => '0.0.0.0',
    '001.2.003.4'          => '1.2.3.4',
    '100.2.3.4'            => '100.2.3.4',
    '10.13.14.015'         => '10.13.14.15',
    '10.33.15.109'         => '10.33.15.109',
    '1.2.3.4.5'            => ''
);

while( my($ip, $cleanip) = each %ips ) {
    is( cleanIP($ip), $cleanip,  "cleanIP($ip)" );
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 96 root/usr/lib/perl5/site_perl/esmith/util/network.pm

use esmith::util::network qw(isValidIP);

my @goodIPs = qw(1.2.3.4
0.0.0.0
255.255.255.255
001.002.003.004
1.32.123.213
192.168.0.3
02.19.090.19
                );
                foreach my $ip (@goodIPs) {
                    ok( isValidIP($ip), "valid $ip");
                }

                my @badIPs = qw(256.3.2.4
                -1.39.9.23
                0
                1
                255.255.255.255.0
                239..19.23.12
                1.2.3.4.
                foo.bar.com
            );

            foreach my $ip (@badIPs) {
                ok( !isValidIP($ip), "invalid $ip");
            }



    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 143 root/usr/lib/perl5/site_perl/esmith/util/network.pm

@badports = (98765434, -183, 0, 'bad port', 'a');
@goodports = (67, 23, 1, 54736);

foreach $port (@badports) {
    isnt(esmith::util::network::isValidPort($port), 1);
}
foreach $port (@goodports) {
    is(esmith::util::network::isValidPort($port), 1);
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 180 root/usr/lib/perl5/site_perl/esmith/util/network.pm

$ip1 = '24.123.212.87';
$ip2 = '240.34.216.12';

is(esmith::util::network::cmpIP($ip1, $ip2), -1);
is(esmith::util::network::cmpIP($ip2, $ip1), 1);
is(esmith::util::network::cmpIP($ip1, $ip1), 0);


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

