#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/util/system.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 16 root/usr/lib/perl5/site_perl/esmith/util/system.pm
use_ok('esmith::util::system', 'killall', 'rsync', 'rsync_ssh');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 61 root/usr/lib/perl5/site_perl/esmith/util/system.pm

open(SCRATCH, ">scratch.exe") || die $!;

# XXX Irritating perl bug ends POD processing if it sees /^#!.*perl/
print SCRATCH sprintf <<'ENDING', '/usr/bin/perl';
#!%s -w

sleep 99;
ENDING

close SCRATCH;

END { unlink 'scratch.exe', 'scratch.out' }

chmod 0755, 'scratch.exe' || die $!;
my $pid = open(SCRATCH, "./scratch.exe |");
ok( $pid, 'scratch program started ok' );

ok( killall('USR1', 'scratch.exe'),     'killall returned properly' );
close SCRATCH;  # so scratch.exe responds to the signal and exits

is( kill(9, $pid), 0,    'killall worked' );

# I can't actually think of a way to explicitly check this but it
# will make noise if it doesn't work.
ok( !killall('USR1', 'I_dont_exist_nope'), 
    'returned properly for killing nothing' );
ok( 1, 'killall is quiet when nothing is killed' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 119 root/usr/lib/perl5/site_perl/esmith/util/system.pm

use File::Compare;
my $src  = '10e-smith-lib/db.t';
my $dest = '10e-smith-lib/db.t.copy';
rsync($src, $dest);
END { unlink $dest }

ok( -e $dest );
ok( compare($src, $dest) == 0, 'basic rsync copy' );

open(DEST, ">$dest" ) || die $!;
print DEST "Fooble\n";
close DEST;

# rsync in update-only mode.  $dest is newer than $src and shouldn't
# be updated.
rsync($src, $dest, qw(--update));

ok( compare($src, $dest) == 1,  'rsync, update only' );

open(DEST, "$dest") || die $!;
my $data = join '', <DEST>;
close DEST;

is( $data, "Fooble\n" );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 168 root/usr/lib/perl5/site_perl/esmith/util/system.pm

use File::Compare;
my $src  = '10e-smith-lib/db.t';
my $dest = '10e-smith-lib/db.t.copy';

unlink $dest;
END { unlink $dest }

no warnings 'once';
my @args;
my $real_rsync = \&esmith::util::system::rsync;
local *esmith::util::system::rsync = sub {
    @args = @_;

    pop @_;
    $real_rsync->(@_);
};
        
rsync_ssh($src, $dest, 'someone', 'some/ident', [qw(--update)], [qw(-C)]);
ok( -e $dest );
ok( compare($src, $dest) == 0 );

is($args[0], $src );
is($args[1], $dest );
is($args[2], '--update' );
is($args[3], "-e $esmith::util::system::SSH_CMD -l someone -i some/ident -C");


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

