#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub READ {}
sub READLINE {}
sub GETC {}

my $Original_File = 'root/usr/lib/perl5/site_perl/esmith/templates.pm';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 29 root/usr/lib/perl5/site_perl/esmith/templates.pm
use_ok('esmith::templates');

    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 154 root/usr/lib/perl5/site_perl/esmith/templates.pm

use esmith::HostsDB;
eval {
    processTemplate({ CONFREF   => { foo => "bar" },
                      MORE_DATA => { something => 'other' },
                    });
};
like( $@, qr/^ERROR: Can't use CONFREF with MORE_DATA/ );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 686 root/usr/lib/perl5/site_perl/esmith/templates.pm

use esmith::TestUtils qw(scratch_copy);

my $scratch = scratch_copy('10e-smith-lib/configuration.conf');
$ENV{ESMITH_CONFIG_DB} = $scratch;
use esmith::ConfigDB;
my $db = esmith::ConfigDB->open;
my @recs = $db->get_all;

my $vars = esmith::templates::_init_tmpl_vars({});
is( keys %{$vars->[0]}, grep($_->props >  1, @recs),
                               '  multi-prop ConfigDBs are hashes');
is( keys %{$vars->[1]}, grep($_->props <= 1, @recs),
                               '  single-prop are scalars'); 
is( keys %{$vars->[2]}, 2,     '  confref' );
isa_ok( $vars->[2]{DB}, 'REF', '  objects must be scalar refs for T::T' );
isa_ok( ${$vars->[2]{DB}}, 'esmith::ConfigDB' );
is( keys %{$vars->[3]}, 0,     '  no MORE_DATA' );


$vars = esmith::templates::_init_tmpl_vars({ CONFREF => { foo => 42,
                                                          bar => 23,
                                                        } });
is( keys %{$vars->[0]}, grep($_->props >  1, @recs),
                               '  multi-prop ConfigDBs are hashes');
is( keys %{$vars->[1]}, grep($_->props <= 1, @recs),
                               '  single-prop are scalars'); 
is( keys %{$vars->[2]}, 2,     '  confref' );
is_deeply( ${$vars->[2]{confref}}, { foo => 42, bar => 23 } );
is( keys %{$vars->[3]}, 2,     '  MORE_DATA' );
is( $vars->[3]{foo}, 42 );
is( $vars->[3]{bar}, 23 );


$vars = esmith::templates::_init_tmpl_vars({ MORE_DATA => { foo => 42,
                                                            bar => 23,
                                                          } });
is( keys %{$vars->[0]}, grep($_->props >  1, @recs),
                               '  multi-prop ConfigDBs are hashes');
is( keys %{$vars->[1]}, grep($_->props <= 1, @recs),
                               '  single-prop are scalars'); 
is( keys %{$vars->[2]}, 2,     '  confref' );
is( keys %{$vars->[3]}, 2,     '  MORE_DATA' );
is( $vars->[3]{foo}, 42 );
is( $vars->[3]{bar}, 23 );

my $h_scratch = scratch_copy('10e-smith-lib/hosts.conf');
my $a_scratch = scratch_copy('10e-smith-lib/accounts.conf');
my $c_scratch = scratch_copy('10e-smith-lib/configuration.conf');
$ENV{ESMITH_CONFIG_DB}   = $c_scratch;

$vars = esmith::templates::_init_tmpl_vars();

ok( ref ${ $vars->[2]{confref} } eq 'HASH', 'confref is HASH ref' );



    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 819 root/usr/lib/perl5/site_perl/esmith/templates.pm

my %expect = (
              'templates/template-begin' => 
                                '10e-smith-lib/templates/template-begin',
              'templates/10moof' =>
                                '10e-smith-lib/templates/10moof',
              'templates/template-end' =>
                                '10e-smith-lib/templates/template-end',
             );

my %templates = esmith::templates::_merge_templates('templates', 
                                                    '10e-smith-lib');
is_deeply( \%templates, \%expect, '_merge_templates' );

%expect = (
           'templates2/template-begin' => 
                              '/etc/e-smith/templates-default/template-begin',
           'templates2/10moof' =>
                                '10e-smith-lib/templates2/10moof',
           'templates2/template-end' =>
                                '10e-smith-lib/templates2/template-end',
          );

%templates = esmith::templates::_merge_templates('templates2',
                                                 '10e-smith-lib');
is_deeply( \%templates, \%expect, '_merge_templates() + template-begin' );

%templates = esmith::templates::_merge_templates('templates3',
                                                 '10e-smith-lib');
is( keys %templates, 0 );

# Bug 3110.
%templates = esmith::templates::_merge_templates('templates.t',
                                                 '10e-smith-lib');

%expect = (
    'templates.t' => '10e-smith-lib/templates.t'
);
is_deeply( \%templates, \%expect, 'single file TEMPLATE_PATH' );


%templates = esmith::templates::_merge_templates('10moof',
	     					 '10e-smith-lib/templates2',
						 '10e-smith-lib/templates',
						);

%expect = (
    '10moof' => '10e-smith-lib/templates2/10moof'
);
is_deeply( \%templates, \%expect, 'single file TEMPLATE_PATH' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 955 root/usr/lib/perl5/site_perl/esmith/templates.pm

use POSIX ':locale_h';
use locale;
setlocale(LC_ALL, "en_US");
$esmith::templates::a = '10Ahhh';
$esmith::templates::b = '10ahhh';
is( esmith::templates::_template_order(), -1 );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 998 root/usr/lib/perl5/site_perl/esmith/templates.pm

use esmith::templates qw(removeBlankLines);
is( removeBlankLines("  "), '',         'removeBlankLines whitespace' );
is( removeBlankLines("\t"), '',         '  tabs' );
is( removeBlankLines("\n"), '',         '  newlines' );
is( removeBlankLines(""),   '',         '  empty' );
is( removeBlankLines(" a "), ' a ',     '  not empty' );


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

